-- crafting speed
local base_speed = 1
local speed_factor = 2

-- energy usage
local base_power = 200
local power_factor = 4

-- pollution
local base_pollution = 0.5 / base_power 
        -- keeps the base polution at .. (indipendant from the energy usage)
local pollution_factor = 2 / power_factor 
        -- keeps the pollution factor at .. (indipendant from the energy usage)


function make_replicator(tier, ingredients)
  local t
  local categories = {}
  for t=1, tier do
    categories[#categories+1] = 'replication-' .. t
  end
  if tier > 1 then
    ingredients[#ingredients + 1] = {'replicator-'..(tier-1), 1}
  end
  data:extend({
    {
      type = "recipe",
      name = "replicator-"..tier,
      enabled = "false",
      ingredients = ingredients,
      result = "replicator-"..tier,
      subgroup = 'replicators'
    },
    {
      type = "item",
      name = "replicator-"..tier,
      icon = "__replicators__/graphics/icons/replicator-"..tier..".png",
      flags = {"goes-to-quickbar"},
      subgroup = "production-machine",
      order = "a[assembling-machine-4]",
      place_result = "replicator-"..tier,
      stack_size = 50
    },

    {
      type = "assembling-machine",
      name = "replicator-"..tier,
      icon = "__replicators__/graphics/icons/replicator-"..tier..".png",
      flags = {"placeable-neutral", "placeable-player", "player-creation"},
      minable = {hardness = 0.2, mining_time = 0.5, result = "replicator-"..tier},
      max_health = 200,
      corpse = "big-remnants",
      dying_explosion = "huge-explosion",
      resistances =
      {
        {
          type = "fire",
          percent = 70
        }
      },

      collision_box = {{-0.8, -0.8}, {0.8, 0.8}},
      selection_box = {{-1.0, -1.0}, {1.0, 1.0}},
      light = {intensity = 1.00, size = 8},


      fast_replaceable_group = "replicator",
      animation =
      {
        filename = "__replicators__/graphics/replicator-"..tier..".png",
        priority="high",
        width = 113,
        height = 91,
        frame_count = 33,
        line_length = 11,
        animation_speed = 1/3,
        shift = {0.2, 0.15},
        scale = 0.66
      },
      crafting_categories = categories,
      crafting_speed = base_speed * speed_factor^(tier-1),
      energy_source =
      {
        type = "electric",
        usage_priority = "secondary-input",
        emissions = base_pollution * pollution_factor^(tier-1),
      },
      energy_usage = (base_power * power_factor^(tier-1)) .. "kW",
      module_slots = 1, ---------------------------------------------------------------------------------------------------------------
      allowed_effects = {"consumption", "speed", "productivity", "pollution"},
      ingredient_count = -0,
      open_sound = { filename = "__base__/sound/machine-open.ogg", volume = 0.85 },
      close_sound = { filename = "__base__/sound/machine-close.ogg", volume = 0.75 },
      working_sound =
      {
        sound = {
          {
            filename = "__base__/sound/lab.ogg",
            volume = 0.7
          },
        },
        idle_sound = { filename = "__base__/sound/idle1.ogg", volume = 0.6 },
        apparent_volume = 1.5,
      }
    }
  })
end

make_replicator(1, {
  {"electronic-circuit", 5},
  {"rare-earth-magnet", 2},
  {"iron-plate", 5}
})
make_replicator(2, {
  {"superconductor", 2},
  {"electronic-circuit", 20},
})
make_replicator(3, {
  {"superconductor", 4},
  {"engine-unit", 2},
})
make_replicator(4, {
  {"ion-conduit", 2},
  {"advanced-circuit", 2},
})
make_replicator(5, {
  {"ion-conduit", 4},
  {"processing-unit", 2},
})
